==================
Usage and Examples
==================

Notebooks
=========

These notebooks demonstrate various features and use cases of the
library.

.. toctree::
    :maxdepth: 2
    :caption: Notebooks:

    notebooks/demo
    notebooks/counts
    notebooks/linear-bandits
    notebooks/delayed-reward
    notebooks/persistence
    notebooks/offline-learning
